# Historical Documentation

This directory contains historical documents that are no longer actively maintained but preserved for reference.

## Contents

| Directory/File | Description |
|----------------|-------------|
| [feedback/](./feedback/) | User feedback and compliance analysis from v3.x era |
| [research/](./research/) | One-off experiments and research notes |
| [protocol-evolution.md](./protocol-evolution.md) | Protocol changes v3.5 → v3.6 |
| [original-vision.md](./original-vision.md) | Original vision document |
| [decisions-2024.md](./decisions-2024.md) | Design decisions from 2024 |

## Note

These documents may reference outdated concepts (e.g., ICIDIV workflow, v3.x protocol).
For current documentation, see:

- [INVAR.md](../../INVAR.md) — Current protocol (v5.0)
- [docs/reference/](../reference/) — Technical reference
- [docs/guide.md](../guide.md) — User guide
